OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Beágyazott üzenet %s",
    "Important mail" : "Fontos levelek",
    "No message found yet" : "Nem található üzenet",
    "Set up an account" : "Állítson be egy fiókot",
    "Unread mail" : "Olvasatlan levelek",
    "Important" : "Fontos",
    "Work" : "Munkahelyi",
    "Personal" : "Személyes",
    "To Do" : "Teendő",
    "Later" : "Később",
    "Mail" : "Levelezés",
    "You are reaching your mailbox quota limit for {account_email}" : "Elérte a postafiók kvótát a következő fiókban: {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Jelenleg a postafiók {percentage} használja. Szabadítson fel helyet a szükségtelen levelek törlésével.",
    "Mails" : "Levelek",
    "💌 A mail app for Nextcloud" : "E-mail alkalmazás a Nextcloudhoz",
    "Your session has expired. The page will be reloaded." : "A munkamenet elévült. Az oldal újra lesz töltve.",
    "Drafts are saved in:" : "Piszkozat mentése ide:",
    "Sent messages are saved in:" : "Elküldött üzenetek mentése ide:",
    "Deleted messages are moved in:" : "Törölt üzenetek áthelyezése ide:",
    "Archived messages are moved in:" : "Az archivált üzenetek át lesznek helyezve ide:",
    "Snoozed messages are moved in:" : "Az elaltatott üzenetek ide kerülnek:",
    "Junk messages are saved in:" : "A levélszemét ide kerül:",
    "Connecting" : "Kapcsolódás",
    "Reconnect Google account" : "Google-fiók újbóli csatlakoztatása",
    "Sign in with Google" : "Bejelentkezés a Google-lel",
    "Save" : "Mentés",
    "Connect" : "Kapcsolódás",
    "Looking up configuration" : "Beállítások megkeresése",
    "Checking mail host connectivity" : "Levelezőkiszolgáló kapcsolódásának ellenőrzése",
    "Configuration discovery failed. Please use the manual settings" : "A beállítások felfedezése sikertelen. Használja a kézi beállításokat.",
    "Password required" : "Jelszó szükséges",
    "Testing authentication" : "Hitelesítés tesztelése",
    "Awaiting user consent" : "Várakozás a felhasználó beleegyezésére",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Fiók létrehozva. Kövesse a felugró utasításokat a Google-fiókja csatlakoztatásához.",
    "Loading account" : "Fiók betöltése",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Fiók frissítve. Kövesse a felugró utasításokat a Google-fiókja csatlakoztatásához.",
    "Account updated" : "Fiók frissítve",
    "IMAP server is not reachable" : "Az IMAP-kiszolgáló nem érhető el",
    "SMTP server is not reachable" : "Az SMTP-kiszolgáló nem érhető el",
    "IMAP username or password is wrong" : "Az IMAP-felhasználónév vagy jelszó hibás",
    "SMTP username or password is wrong" : "Az SMTP-felhasználónév vagy jelszó hibás",
    "IMAP connection failed" : "Az IMAP kapcsolódás sikertelen",
    "SMTP connection failed" : "Az SMTP kapcsolódás sikertelen",
    "Authorization pop-up closed" : "Hitelesítési felugró ablak bezárva",
    "Configuration discovery temporarily not available. Please try again later." : "A konfiguráció felderítése jelenleg nem lehetséges. Kérjük próbálja meg később.",
    "There was an error while setting up your account" : "Hiba történt a fiók beállítása során",
    "Auto" : "Automatikus",
    "Name" : "Név",
    "Mail address" : "E-mail-cím",
    "name@example.org" : "nev@example.org",
    "Please enter an email of the format name@example.com" : "Adja meg a nev@exampl.com formátumú e-mail-címet",
    "Password" : "Jelszó",
    "Manual" : "Kézi",
    "IMAP Settings" : "IMAP beállítások",
    "IMAP Host" : "IMAP kiszolgáló",
    "IMAP Security" : "IMAP biztonság",
    "None" : "Semmi",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP felhasználó",
    "IMAP Password" : "IMAP jelszó",
    "SMTP Settings" : "SMTP beállítások",
    "SMTP Host" : "SMTP kiszolgáló",
    "SMTP Security" : "SMTP biztonság",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP felhasználó",
    "SMTP Password" : "SMTP jelszó",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Ahhoz, hogy a Google-fiókja működjön ezzel az alkalmazással, engedélyeznie kell a kétfaktoros hitelesítést, és elő kell állítania egy alkalmazásjelszót.",
    "Account settings" : "Fiókbeállítások",
    "Aliases" : "Álnevek",
    "Alias to S/MIME certificate mapping" : "Álnév az S/MIME tanúsítvány-hozzárendeléshez",
    "Signature" : "Aláírás",
    "A signature is added to the text of new messages and replies." : "Az aláírás hozzáadásra kerül az új levelekhez és válaszokhoz.",
    "Writing mode" : "Írási mód",
    "Preferred writing mode for new messages and replies." : "Előnyben részesített írási stílus az új levelekhez.",
    "Default folders" : "Alapértelmezett mappák",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "A piszkozatokhoz, az elküldött, a törölt és az archivált levelekhez használandó mappák.",
    "Automatic trash deletion" : "Automata szemét törlés",
    "Days after which messages in Trash will automatically be deleted:" : "A napok száma, ami után a Szemétben lévő üzenetek automatikusan törlésre kerülnek:",
    "Autoresponder" : "Automatikus válaszoló",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatikus válasz a beérkező üzenetekre. Ha valaki több üzenetet is küld, akkor az automatikus válasz legfeljebb 4 naponta lesz elküldve.",
    "Filters" : "Szűrők",
    "Mail server" : "Levelezőkiszolgáló",
    "Update alias" : "Álnév frissítése",
    "Rename alias" : "Álnév átnevezése",
    "Show update alias form" : "Álnév frissítési űrlap megjelenítése",
    "Delete alias" : "Álnév törlése",
    "Go back" : "Visszalépés",
    "Change name" : "Név megváltoztatása",
    "Email address" : "E-mail-cím",
    "Add alias" : "Álnév hozzáadása",
    "Create alias" : "Álnév létrehozása",
    "Cancel" : "Mégse",
    "Put my text to the bottom of a reply instead of on top of it." : "A szöveg a válasz aljára helyezése a teteje helyett.",
    "Could not update preference" : "Nem sikerült frissíteni a beállítást",
    "Mail settings" : "Levelezési beállítások",
    "Accounts" : "Fiókok",
    "Add mail account" : "E-mail-fiók hozzáadása",
    "General" : "Általános",
    "List" : "Lista",
    "Sorting" : "Rendezés",
    "Newest" : "Legújabb",
    "Oldest" : "Legrégebbi",
    "Use Gravatar and favicon avatars" : "Gravatar és favicon profilképek használata",
    "Register as application for mail links" : "Alkalmazás beállítása a levélhivatkozásokhoz",
    "Register" : "Regisztráció",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Engedélyezés az alkalmazásnak, hogy az adatokat gyűjtsön az interakcióiról. Az adatok alapján az alkalmazás alkalmazkodni fog a használati szokásaihoz. Az adatok helyben lesznek tárolva.",
    "Trusted senders" : "Megbízható küldők",
    "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése",
    "Looking for a way to encrypt your emails?" : "Azt keresi, hogyan titkosíthatná a leveleit?",
    "About" : "Névjegy",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Compose new message" : "Új üzenet írása",
    "Newer message" : "Újabb üzenet",
    "Older message" : "Régebbi üzenet",
    "Toggle star" : "Csillagozás be/ki",
    "Toggle unread" : "Olvasatlan be/ki",
    "Archive" : "Archívum",
    "Delete" : "Törlés",
    "Search" : "Keresés",
    "Send" : "Küldés",
    "Refresh" : "Frissítés",
    "No certificate" : "Nincs tanúsítvány",
    "Certificate updated" : "Tanúsítvány frissítve",
    "Could not update certificate" : "A tanúsítvány frissítése nem sikerült",
    "{commonName} - Valid until {expiryDate}" : "{commonName} – Eddig érvényes: {expiryDate}",
    "Select an alias" : "Válasszon álnevet",
    "Update Certificate" : "Tanúsítvány frissítése",
    "Encrypt with S/MIME and send later" : "Titkosítás S/MIME-mal és elküldés később",
    "Encrypt with S/MIME and send" : "Titkosítás S/MIME-mal és elküldés",
    "Encrypt with Mailvelope and send later" : "Titkosítás Mailvelope-pal és elküldés később",
    "Encrypt with Mailvelope and send" : "Titkosítás Mailvelope-pal és elküldés",
    "Send later" : "Küldés később",
    "Message {id} could not be found" : "A(z) {id} üzenet nem található",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Az S/MIME-mal történő aláírás vagy titkosítás ki lett választva, de nincs tanúsítvány a kiválasztott álnévhez. Az üzenet nem lesz aláírva vagy titkosítva.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Minden meglévő formázás (például félkövér, dőlt és aláhúzott szöveg vagy beszűrt képek) eltávolításra kerül.",
    "Turn off formatting" : "Formázás kikapcsolása",
    "Turn off and remove formatting" : "Formázás kikapcsolása és eltávolítása",
    "Keep formatting" : "Formázás megtartása",
    "From" : "Feladó",
    "Select account" : "Fiók kiválasztása",
    "To" : "Címzett",
    "Select recipient" : "Válasszon címzettet",
    "Contact or email address …" : "Címzett vagy e-mail-cím…",
    "Cc" : "Másolat",
    "Bcc" : "Rejtett másolat",
    "Subject" : "Tárgy",
    "Subject …" : "Tárgy…",
    "This message came from a noreply address so your reply will probably not be read." : "Vegye figyelembe, hogy a levél egy „ne válaszoljon” címről érkezett, így a válaszát valószínűleg nem fogják elolvasni.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "A következő címzettek nem rendelkeznek S/MIME-tanúsítvánnyal: {recipents}",
    "The following recipients do not have a PGP key: {recipients}." : "A következő címzettek nem rendelkeznek PGP kulccsal: {recipents}",
    "Write message …" : "Üzenet írása…",
    "Saving draft …" : "Piszkozat mentése…",
    "Error saving draft" : "Hiba a piszkozat mentése során",
    "Draft saved" : "Vázlat elmentve",
    "Save draft" : "Piszkozat mentése",
    "Discard & close draft" : "Piszkozat elvetése és bezárása",
    "Enable formatting" : "Formázás engedélyezése",
    "Disable formatting" : "Formázás letiltása",
    "Upload attachment" : "Melléklet feltöltése",
    "Add attachment from Files" : "Melléklet hozzáadása a Fájlokból",
    "Smart picker" : "Okos választó",
    "Request a read receipt" : "Tértivevény kérése",
    "Sign message with S/MIME" : "Üzenetek aláírása S/MIME-mal",
    "Encrypt message with S/MIME" : "Üzenetek titkosítása S/MIME-mal",
    "Encrypt message with Mailvelope" : "Üzenet titkosítása a Mailvelope-pal",
    "Send now" : "Küldés most",
    "Tomorrow morning" : "Holnap reggel",
    "Tomorrow afternoon" : "Holnap délutá",
    "Monday morning" : "Hétfő reggel",
    "Custom date and time" : "Egyéni dátum és idő",
    "Enter a date" : "Adjon meg egy dátumot",
    "Choose" : "Válasszon",
    "Choose a file to add as attachment" : "Válasszon mellékletként hozzáadandó fájlt",
    "Choose a file to share as a link" : "Válasszon fájlt a hivatkozással történő megosztáshoz",
    "_{count} attachment_::_{count} attachments_" : ["{count} melléklet","{count} melléklet"],
    "Untitled message" : "Névtelen üzenet",
    "Expand composer" : "Szerkesztő kibontása",
    "Close composer" : "Szerkesztő bezárása",
    "Confirm" : "Megerősítés",
    "Plain text" : "Egyszerű szöveg",
    "Rich text" : "Formázott szöveg",
    "No messages in this mailbox" : "Nincs üzenet ebben a postafiókban",
    "No messages" : "Nincs üzenet",
    "Blind copy recipients only" : "Csak a rejtett másolatok címzettjei",
    "No subject" : "Nincs tárgy",
    "Later today – {timeLocale}" : "Később a mai nap – {timeLocale}",
    "Set reminder for later today" : "Emlékeztető beállítása a mai napon későbbre",
    "Tomorrow – {timeLocale}" : "Holnap – {timeLocale}",
    "Set reminder for tomorrow" : "Emlékeztető beállítása holnapra",
    "This weekend – {timeLocale}" : "Ez a hétvége – {timeLocale}",
    "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
    "Next week – {timeLocale}" : "Következő hét – {timeLocale}",
    "Set reminder for next week" : "Emlékeztető beállítása a következő hétre",
    "No trash mailbox configured" : "Nincs mappa beállítva a törölt üzenetek számára",
    "Could not delete message" : "Nem sikerült törölni az üzenetet",
    "Could not archive message" : "Az üzenet archiválása sikertelen",
    "Thread was snoozed" : "Fel lett függesztve a szál/folyamat",
    "Could not snooze thread" : "Nem lehet felfügegszteni a szálat/folyamatot",
    "Thread was unsnoozed" : "Folyatódott a szál/folyamat ",
    "Could not unsnooze thread" : "Nem lehet folytatni a szálat/folyamatot ",
    "Draft: " : "Piszkozat: ",
    "Encrypted message" : "Titkosított üzenet",
    "This message is unread" : "Ez az üzenet olvasatlan",
    "Unfavorite" : "Nem kedvenc",
    "Favorite" : "Kedvenc",
    "Unread" : "Olvasatlan",
    "Read" : "Olvasott",
    "Unimportant" : "Nem fontos",
    "Mark not spam" : "Levélszemétnek jelölés visszavonása",
    "Mark as spam" : "Levélszemétnek jelölés",
    "Edit tags" : "Címkék szerkesztése",
    "Snooze" : "Altatás",
    "Unsnooze" : "Felébresztés",
    "Move thread" : "Szál áthelyezése",
    "Archive thread" : "Szál archiválása",
    "Archive message" : "Üzenet archiválása",
    "Delete thread" : "Szál törlése",
    "Delete message" : "Üzenet törlése",
    "More actions" : "További műveletek",
    "Back" : "Vissza",
    "Set custom snooze" : "Egyéni altatás beállítása",
    "Edit as new message" : "Szerkesztés új üzenetként",
    "Create event" : "Esemény létrehozása",
    "Create task" : "Feladat létrehozása",
    "Download message" : "Üzenet letöltése",
    "Load more" : "Továbbiak betöltése",
    "_Mark {number} read_::_Mark {number} read_" : ["{number} olvasottnak jelölése","{number} olvasottnak jelölése"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["{number} olvasatlannak jelölése","{number} olvasatlannak jelölése"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["{number} fontosnak jelölése","{number} fontosnak jelölése"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["{number} fontosnak jelölésének visszavonása","{number} fontosnak jelölésének visszavonása"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["{number} kedvencnek jelölés visszavonása","{number} kedvencnek jelölés visszavonása"],
    "_Favorite {number}_::_Favorite {number}_" : ["{number} kedvencnek jelölés","{number} kedvencnek jelölés"],
    "_Unselect {number}_::_Unselect {number}_" : ["{number} kiválasztásának megszüntetése","{number} kiválasztásának megszüntetése"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["{number} megjelölése levélszemétként","{number} megjelölése levélszemétként"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number} megjelölése nem levélszemétként","{number} megjelölése nem levélszemétként"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["{number} címkéinek szerkesztése","{number} címkéinek szerkesztése"],
    "_Move {number} thread_::_Move {number} threads_" : ["{number} szál áthelyezése","{number} szál áthelyezése"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["{number} továbbítása mellékletként","{number} továbbítása mellékletként"],
    "Report this bug" : "A hiba bejelentése",
    "Event created" : "Esemény létrehozása",
    "Could not create event" : "Nem sikerült létrehozni az eseményt",
    "All day" : "Egész nap",
    "Select calendar" : "Válasszon naptárat",
    "Description" : "Leírás",
    "Create" : "Létrehozás",
    "This event was updated" : "Ezt az eseményt frissítették",
    "{attendeeName} accepted your invitation" : "{attendeeName} elfogadta a meghívását",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} feltételesen elfogadta a meghívását",
    "{attendeeName} declined your invitation" : "{attendeeName} elutasította a meghívását",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reagált a meghívására",
    "Failed to save your participation status" : "A részvételi állapotának mentése sikertelen",
    "You accepted this invitation" : "Elfogadta ezt a meghívást",
    "You tentatively accepted this invitation" : "Feltételesen elfogadta ezt a meghívást",
    "You declined this invitation" : "Elutasította ezt a meghívást",
    "You already reacted to this invitation" : "Már reagált erre a meghívásra",
    "You have been invited to an event" : "Meghívták egy eseményre",
    "This event was cancelled" : "Ezt az eseményt lemondták",
    "Save to" : "Mentés másként",
    "Select" : "Kiválasztás",
    "Comment" : "Megjegyzés",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "Tentatively accept" : "Elfogadás feltételesen",
    "More options" : "További lehetőségek",
    "Could not remove internal address {sender}" : "A belső cím nem távolítható el: {sender}",
    "Could not add internal address {address}" : "A belső cím nem addható hozzá: {address}",
    "individual" : "egyéni",
    "domain" : "domain",
    "Remove" : "Eltávolítás",
    "email" : "e-mail",
    "Add internal address" : "Belső cím hozzáadása",
    "Add internal email or domain" : "Belső e-mail vagy tartomány hozzáadása",
    "Itinerary for {type} is not supported yet" : "A(z) {type} útiterve még nem támogatott",
    "To archive a message please configure an archive mailbox in account settings" : "Egy üzenet archiválásához állítsa be az archiváláshoz használt postafiókot a fiókbeállításokban",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nem helyezheti át ezt az üzenetet az archiválási mappába vagy törölheti a jelenlegi mappából",
    "Could not open mailbox" : "Nem sikerült megnyitni a postaládát",
    "Loading messages …" : "Üzenetek betöltése…",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Üzenetek indexelése folyamatban. Ez a folyamat tovább tarthat a nagyobb méretű postafiókok esetén.",
    "Choose target mailbox" : "Válasszon cél postafiókot",
    "No more submailboxes in here" : "Nem találhatók további alpostafiókok",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Az üzeneteket automatikusan fontosként jelöli meg az alapján, hogy mely üzenetekre reagált, vagy jelölt meg fontosként. Kezdetben lehet, hogy kézzel megváltoztatnia a fontosságot és ezzel kell tanítania a rendszert, de ez az idő múlásával javulni fog.",
    "Follow up" : "Emlékeztető",
    "Follow up info" : "Emlékeztető információ",
    "Important info" : "Fontos információ",
    "Other" : "Egyéb",
    "Could not send mdn" : "Az mdn küldése sikertelen",
    "The sender of this message has asked to be notified when you read this message." : "A küldő tértivevényt kért az üzenet elolvasásáról.",
    "Notify the sender" : "Küldő értesítése",
    "You sent a read confirmation to the sender of this message." : "Tértivevény küldött a küldőnek az üzenet elolvasásáról.",
    "Message was snoozed" : "Az üzenet el lett altatva",
    "Could not snooze message" : "Nem sikerült az üzenet elaltatása",
    "Message was unsnoozed" : "Az üzenet fel lett ébresztve",
    "Could not unsnooze message" : "Nem sikerült az üzenet felébresztése",
    "Forward" : "Továbbítás",
    "Move message" : "Üzenet áthelyezése",
    "Translate" : "Lefordítás",
    "Forward message as attachment" : "Üzenet továbbítása mellékletként",
    "View source" : "Forrás megtekintése",
    "Download thread data for debugging" : "Szálak adatainak letöltése hibakeresés céljából",
    "Message body" : "Üzenet törzse",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Figyelmeztetés: Az üzenet S/MIME aláírása nincs ellenőrizve. Lehet, hogy a küldő megszemélyesít valakit.",
    "Unnamed" : "Névtelen",
    "Embedded message" : "Beágyazott üzenet",
    "calendar imported" : "naptár importálva",
    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához",
    "Import into calendar" : "Betöltés a naptárba",
    "Download attachment" : "Melléklet letöltése",
    "Save to Files" : "Mentés a Fájlokba",
    "View fewer attachments" : "Kevesebb melléklet megtekintése",
    "Choose a folder to store the attachments in" : "Válasszon egy mappát a mellékletek tárolásához",
    "Save all to Files" : "Minden mentése a Fájlokba",
    "Download Zip" : "Letöltés ZIP-fájlként",
    "_View {count} more attachment_::_View {count} more attachments_" : ["{count} további melléklet megtekintése","{count} további melléklet megtekintése"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Ez az üzenet PGP-vel van titkosítva. A visszafejtéshez telepítse a Mailvelope kiegészítőt.",
    "The images have been blocked to protect your privacy." : "Az adatvédelme érdekében a képek le lettek tiltva.",
    "Show images" : "Képek megjelenítése",
    "Show images temporarily" : "Képek ideiglenes megjelenítése",
    "Always show images from {sender}" : "Mindig jelenítse meg a képeket a következőtől: {sender}",
    "Always show images from {domain}" : "Mindig jelenítse meg a képeket a(z) {domain} domainről",
    "Message frame" : "Üzenetkeret",
    "Quoted text" : "Idézett szöveg",
    "Move" : "Áthelyezés",
    "Moving" : "Áthelyezés",
    "Moving thread" : "Szál áthelyezése",
    "Moving message" : "Üzenet áthelyezése",
    "Loading …" : "Betöltés…",
    "Not supported by the server" : "A kiszolgáló nem támogatja",
    "{usage} of {limit} used" : "{usage} / {limit} felhasználva",
    "Remove account" : "Fiók eltávolítása",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Az {email} fiók és a gyorsítótárazott e-mail-adatok el lesznek távolítva a Nextcloudból, az e-mail-szolgáltatójától azonban nem.",
    "Remove {email}" : "{email} eltávolítása",
    "Provisioned account is disabled" : "A felügyelt fiók le van tiltva",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Jelentkezzen be a jelszóval, hogy engedélyezze a fiókot. A jelenlegi munkamenet jelszó nélküli hitelesítést használ, például SSO-t vagy WebAuthnt.",
    "Quota" : "Kvóta",
    "Show only subscribed mailboxes" : "Csak a feliratkozott postafiókok megjelenítése",
    "Add mailbox" : "Postaláda hozzáadása",
    "Mailbox name" : "Postafiók név",
    "Saving" : "Mentés",
    "Move up" : "Mozgatás fel",
    "Move down" : "Mozgatás le",
    "Show all subscribed mailboxes" : "Összes feliratkozott postafiók megjelenítése",
    "Show all mailboxes" : "Összes postafiók megjelenítése",
    "Collapse mailboxes" : "Postaládák összecsukása",
    "_{total} message_::_{total} messages_" : ["{total} üzenet","{total} üzenet"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} olvasatlan az összesen {total} üzenetből","{unread} olvasatlan az összesen {total} üzenetből"],
    "All messages in mailbox will be deleted." : "A postaládában lévő összes üzenet végleges törlésre kerül.",
    "Clear mailbox {name}" : "A(z) {name} postaláda ürítése",
    "Clear mailbox" : "Postaláda ürítése",
    "The mailbox and all messages in it will be deleted." : "A postafiók és az abban található összes üzenet törlődik.",
    "Delete mailbox" : "Fiók törlése",
    "Delete mailbox {name}" : "A(z) {name} postafiók törlése",
    "An error occurred, unable to rename the mailbox." : "Hiba történt, nem sikerült átnevezni a postafiókot.",
    "Mark all as read" : "Összes megjelölése olvasottként",
    "Mark all messages of this mailbox as read" : "Postafiók összes üzenetének megjelölése olvasottként",
    "Add submailbox" : "Alpostaláda hozzáadása",
    "Rename" : "Átnevezés",
    "Move mailbox" : "Postaláda áthelyezése",
    "Clear cache" : "Gyorsítótár ürítése",
    "Clear locally cached data, in case there are issues with synchronization." : "Törölje a helyileg gyorsítótárazott adatokat, ha a szinkronizálással kapcsolatban problémák merülnének fel.",
    "Subscribed" : "Feliratkozott",
    "Sync in background" : "Szinkronizálás a háttérben",
    "Outbox" : "Kimenő üzenetek",
    "New message" : "Új üzenet",
    "Edit message" : "Üzenet szerkesztése",
    "Draft" : "Piszkozat",
    "Reply" : "Válasz",
    "Message saved" : "Üzenet mentve",
    "Failed to save message" : "Nem sikerült menteni az üzenetet",
    "Failed to save draft" : "Nem sikerült menteni a piszkozatot",
    "attachment" : "melléklet",
    "attached" : "mellékelve",
    "No sent mailbox configured. Please pick one in the account settings." : "Nincs beállítva mappa az elküldött üzenetek számára. Állítson be egyet a fiókbeállításokban.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Sok címzettnek próbál küldeni a Címzett vagy a Másolat mezőben. Fontolja meg a Rejtett másolat használatát a címzettek elrejtéséhez.",
    "You mentioned an attachment. Did you forget to add it?" : "Mellékletet említett. Nem felejtette el hozzáadni?",
    "Message discarded" : "Üzenet elvetése",
    "Could not discard message" : "Nem sikerült elvetni az üzenetet",
    "Minimize composer" : "Szerkesztő összecsukása",
    "Error sending your message" : "Hiba az üzenete elküldésekor",
    "Retry" : "Újra",
    "Warning sending your message" : "Figyelmeztetés az üzenet elküldésekor",
    "Send anyway" : "Elküldés mindenképpen",
    "Autoresponder off" : "Automatikus válaszoló ki",
    "Autoresponder on" : "Automatikus válaszoló be",
    "First day" : "Első nap",
    "Last day (optional)" : "Utolsó nap (nem kötelező)",
    "${subject} will be replaced with the subject of the message you are responding to" : "A ${subject} le lesz cserélve annak az üzenetnek a tárgyára, amelyre válaszol.",
    "Message" : "Üzenet",
    "Oh Snap!" : "Hoppá!",
    "Save autoresponder" : "Automatikus válaszoló mentése",
    "Could not open outbox" : "Nem sikerült megnyitni a kimenő leveleket",
    "Pending or not sent messages will show up here" : "A függőben lévő vagy el nem küldött üzenetek itt fognak megjelenni",
    "Message could not be sent" : "Az üzenetet nem sikerült elküldeni",
    "Message deleted" : "Üzenet törölve",
    "Copied email address to clipboard" : "Az e-mail a vágólapra másolva",
    "Could not copy email address to clipboard" : "Nem sikerült az e-mail-cím vágólapra másolása",
    "Contacts with this address" : "Névjegyek ezzel a címmel",
    "Add to Contact" : "Hozzáadás a Névjegyekhez",
    "New Contact" : "Új névjegy",
    "Copy to clipboard" : "Másolás a vágólapra",
    "Contact name …" : "Névjegyhez tartozó név…",
    "Add" : "Hozzáadás",
    "Show less" : "Kevesebb megjelenítése",
    "Show more" : "Több megjelenítése",
    "Clear" : "Törlés",
    "Search in mailbox" : "Keresés a postaládában",
    "Close" : "Bezárás",
    "Search parameters" : "Keresési paraméterek",
    "Body" : "Törzs",
    "Date" : "Dátum",
    "Pick a start date" : "Válasszon kezdési dátumot",
    "Pick an end date" : "Válasszon befejezési dátumot",
    "Select senders" : "Válasszon feladókat",
    "Select recipients" : "Válasszon címzetteket",
    "Select CC recipients" : "Válasszon másolatot kapó címzetteket",
    "Select BCC recipients" : "Válasszon vakmásolatot kapó címzetteket",
    "Tags" : "Címkék",
    "Select tags" : "Címkék kiválasztása",
    "Marked as" : "Megjelölés mint",
    "Has attachments" : "Van melléklete",
    "Last 7 days" : "Előző 7 nap",
    "Sieve Port" : "Levélszűrő port",
    "Custom" : "Egyéni",
    "Sieve User" : "Levélszűrő felhasználó",
    "Sieve Password" : "Levélszűrő jelszó",
    "Save sieve settings" : "Levélszűrő beállítások mentése",
    "The syntax seems to be incorrect:" : "A szintaxis helytelennek tűnik:",
    "Save sieve script" : "Levélszűrő parancsfájl mentése",
    "Signature …" : "Aláírás…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Az aláírás 2 MB-nál nagyobb. Ez hatással lehet a szerkesztő teljesítményére",
    "Save signature" : "Aláírás mentése",
    "Place signature above quoted text" : "Az aláírás az idézett szöveg fölé helyezése",
    "An error occurred, unable to rename the tag." : "Hiba történt, a címke nem nevezhető át",
    "Edit name or color" : "Név vagy szín szerkesztése",
    "Saving new tag name …" : "Új címkenév mentése…",
    "Delete tag" : "Címke törlése",
    "Set tag" : "Címke beállítása",
    "Unset tag" : "Címke eltávolítása",
    "Tag name is a hidden system tag" : "A címkenév egy rejtett rendszercímke",
    "Tag already exists" : "A címke már létezik",
    "An error occurred, unable to create the tag." : "HIba történt, a címke nem hozható létre.",
    "Add default tags" : "Alapértelmezett címkék hozzáadása",
    "Add tag" : "Címke hozzáadása",
    "Saving tag …" : "Címke mentése…",
    "Task created" : "Feladat létrehozva",
    "Could not create task" : "Nem sikerült létrehozni a feladatot",
    "No calendars with task list support" : "Nincs feladatlista támogatással rendelkező naptár",
    "Could not load your message thread" : "Nem sikerült betölteni az üzenetszálat",
    "The thread doesn't exist or has been deleted" : "Ez a szál nem létezik vagy törölve lett",
    "Loading thread" : "Szál betöltése",
    "Not found" : "Nem található",
    "Encrypted & verified " : "Titkosított és ellenőrzött",
    "Signature verified" : "Az aláírás ellenőrizve",
    "Signature unverified " : "Az aláírás nincs ellenőrizve",
    "This message was encrypted by the sender before it was sent." : "Ezt az üzenetet az elküldése előtt titkosította a feladó.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Az üzenet ellenőrzött S/MIME digitális aláírást tartalmaz. Az üzenet nem változott, mert már el lett küldve.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Az üzenet nem ellenőrzött S/MIME digitális aláírást tartalmaz. Az üzenetet megváltoztathatták, mert az aláíró tanúsítványa nem megbízható",
    "Reply all" : "Válasz mindenkinek",
    "Unsubscribe request sent" : "Leiratkozási kérés elküldve",
    "Could not unsubscribe from mailing list" : "Nem sikerült a leiratkozás a levelezőlistáról",
    "Unsubscribe" : "Leiratkozás",
    "Reply to sender only" : "Válasz csak a feladónak",
    "Mark as unfavorite" : "Megjelölés nem kedvencként",
    "Mark as favorite" : "Megjelölés kedvencként",
    "Mark as unread" : "Megjelölés olvasatlanként",
    "Mark as read" : "Megjelölés olvasottként",
    "Message source" : "Üzenet forrása",
    "Unsubscribe via link" : "Leiratkozás hivatkozással",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "A leiratkozás leállít minden üzenetet, amely a(z) {sender} levelezőlistáról érkezik",
    "Send unsubscribe email" : "Leiratkozási e-mail küldése",
    "Unsubscribe via email" : "Leiratkozás e-mailben",
    "{name} Assistant" : "{name} Asszisztens",
    "Go to latest message" : "Ugrás a legrégebbi üzenethez",
    "Go to newest message" : "Ugrás a legújabb üzenethez",
    "The message could not be translated" : "Az üzenetet nem sikerült lefordítani",
    "Translation copied to clipboard" : "A fordítás a vágólapra másolva",
    "Translation could not be copied" : "A fordítást nem lehetett másolni",
    "Translate message" : "Üzenet lefordítása",
    "Source language to translate from" : "Fordítás forrásnyelve",
    "Translate from" : "Fordítás a következőről:",
    "Target language to translate into" : "Fordítás célnyelve",
    "Translate to" : "Fordítás a következőre:",
    "Translating" : "Fordítás ",
    "Copy translated text" : "Lefordított szöveg másolása",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Tiltsa le a lomtár megőrzését úgy, hogy üresen hagyja a mezőt, vagy állítsa 0-ra. Csak azokat a leveleket dolgozza fel a rendszer, amelyeket a kukák megőrzésének engedélyezése után töröltek.",
    "Could not remove trusted sender {sender}" : "Nem sikerült eltávolítani a megbízható küldőt: {sender}",
    "No senders are trusted at the moment." : "Jelenleg egyetlen küldő sem megbízható.",
    "Untitled event" : "Névtelen esemény",
    "(organizer)" : "(szervező)",
    "Import into {calendar}" : "Betöltés ide: {calendar}",
    "Event imported into {calendar}" : "Esemény importálva ide: {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{FlightNr} járat {depAirport} és {arrAirport} között",
    "Airplane" : "Repülő",
    "Reservation {id}" : "Foglalás {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} vonat {depStation} és {arrStation} között",
    "Train from {depStation} to {arrStation}" : "Vonat {depStation} és {arrStation} között",
    "Train" : "Vonat",
    "Flag" : "Zászló",
    "Recipient" : "Címzett",
    "Delete filter" : "Szűrő törlése",
    "Operator" : "Állapot",
    "contains" : "tartalmazza",
    "matches" : "egyezik",
    "Filter name" : "Név szűrése",
    "Priority" : "Prioritás",
    "Successfully updated config for \"{domain}\"" : "A(z) „{domain}” konfigurációja sikeresen frissítve",
    "Error saving config" : "Hiba a konfiguráció mentése során",
    "Saved config for \"{domain}\"" : "Konfiguráció mentése ehhez: „{domain}”",
    "Could not save provisioning setting" : "A felügyeleti beállítás nem menthető",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} fiók felügyelete sikeresen beállítva.","{count} fiók felügyelete sikeresen beállítva."],
    "There was an error when provisioning accounts." : "Hiba történt a fiókok felügyeletének beállítása során.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Sikeresen törölve, és a(z) „{domain}” fiókjainak felügyelete megszüntetve",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Hiba történt a törlés és a(z) „{domain}” fiókjainak felügyeletének megszüntetése során",
    "Mail app" : "Levelező alkalmazás",
    "The mail app allows users to read mails on their IMAP accounts." : "A levelezőalkalmazás lehetővé teszi a felhasználók számára, hogy az IMAP-fiókokon olvassák a leveleket.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Itt találhatók a példányszintű beállítások. A felhasználóspecifikus beállításokat magában az alkalmazásban találja (a bal alsó sarokban).",
    "Account provisioning" : "Fiókfelügyelet",
    "A provisioning configuration will provision all accounts with a matching email address." : "A felügyeleti konfiguráció beállítja az összes olyan fiókot, amelyhez megfelelő e-mail-cím tartozik.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "A dzsóker (*) használata a felügyeleti tartománynál olyan konfigurációt hoz létre, amely minden olyan felhasználóra vonatkozik, melyek nem felelnek meg más konfigurációnak.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "A felügyeleti mechanizmus előnyben részesíti a konkrét tartományra vonatkozó konfigurációkat a dzsóker tartománykonfigurációval szemben.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Ha egy új megfelelő konfiguráció található, de a felhasználó már egy másik konfigurációval lett ellátva, akkor az új konfigurációé lesz az elsőbbség, és a felhasználó azzal lesz ellátva.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Tartományonként csak egy konfiguráció lehet, és dzsóker tartománykonfigurációból is csak egy lehet",
    "These settings can be used in conjunction with each other." : "Ezek a beállítások együtt is használhatók.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Ha csak egy domaint akar létrehozni az összes felhasználónak, akkor használja a dzsókert (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ennek a beállításnak akkor van a legtöbb értelme, ha ugyanazt a háttérrendszert használja a Nextcloudhoz és a szervezete levelezőkiszolgálójához.",
    "Provisioning Configurations" : "Felügyeleti konfigurációk",
    "Add new config" : "Új konfiguráció hozzáadása",
    "Provision all accounts" : "Összes fiók felügyelete",
    "Allow additional mail accounts" : "További postafiókok engedélyezése",
    "Allow additional Mail accounts from User Settings" : "További levelezőfiókok hozzáadásának engedélyezése a Felhasználói beállításokból",
    "Anti Spam Service" : "Levélszemét elleni szolgáltatás",
    "You can set up an anti spam service email address here." : "Itt állíthatja be a levélszemét elleni szolgáltatás e-mail-címét.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Minden levélszemétnek jelölt levél el lesz küldve a levélszemét elleni szolgáltatásnak.",
    "Gmail integration" : "Gmail-integráció",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "A Gmail lehetővé teszi, hogy a felhasználók IMAP-on keresztül érjék el az e-mailjeiket. Biztonsági okokból ez csak OAuth 2.0-s kapcsolattal lehetséges, vagy olyan Google-fiókkal, amely kétfaktoros hitelesítést és alkalmazásjelszavakat használ.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Regisztrálnia kell egy új kliensazonosítót egy webalkalmazáshoz a Google Cloud konzolon. Adja meg a {url} webcímet engedélyezett átirányítási címként.",
    "Microsoft integration" : "Microsoft integráció",
    "Successfully set up anti spam email addresses" : "Sikeresen beállította a levélszemét elhárítási e-mail-címeket",
    "Error saving anti spam email addresses" : "Hiba történt a levélszemét elhárítási e-mail-címek mentése során",
    "Successfully deleted anti spam reporting email" : "Levélszemét bejelentési e-mail-cím sikeresen törölve",
    "Error deleting anti spam reporting email" : "Hiba történt a levélszemét bejelentési e-mail-cím törlése során",
    "Anti Spam" : "Levélszemét elhárítás",
    "Add the email address of your anti spam report service here." : "Itt adja hozzá a levélszemét bejelentési szolgáltatása e-mail-címét.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Ha ezt a beállítást használja, akkor egy jelentési levél lesz küldve a levélszemét bejelentési kiszolgálónak, ha egy felhasználó a „Megjelölés levélszemétként” gombra kattint.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Az eredeti üzenet „message/rfc822” mellékletként lesz csatolva.",
    "\"Mark as Spam\" Email Address" : "„Megjelölés levélszemétként” e-mail-címe",
    "\"Mark Not Junk\" Email Address" : "„Megjelölés nem levélszemétként” e-mail-címe",
    "Reset" : "Visszaállítás",
    "Google integration configured" : "A Google-integráció beállítva",
    "Could not configure Google integration" : "Nem sikerült a Google-integráció beállítása",
    "Google integration unlinked" : "Google-integráció bontva",
    "Could not unlink Google integration" : "Nem sikerült a Google-integráció bontása",
    "Client ID" : "Kliensazonosító",
    "Client secret" : "Klienstitok",
    "Unlink" : "Kapcsolat bontása",
    "Microsoft integration configured" : "Microsoft integráció beállítva",
    "Could not configure Microsoft integration" : "Nem sikerült a Microsoft integráció beállítása",
    "Microsoft integration unlinked" : "Microsoft integráció szétkapcsolva",
    "Could not unlink Microsoft integration" : "Nem sikerült a Microsoft integráció szétkapcsolása",
    "Tenant ID (optional)" : "Bérlőazonosító (nem kötelező)",
    "Domain Match: {provisioningDomain}" : "Megfelelő tartomány: {provisioningDomain}",
    "Email: {email}" : "E-mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} itt {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} itt {host}:{port} ({ssl} encryption)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Levélszűrő: {user} a {host} gazdagépen: {port} ({ssl} titkosítás)",
    "Configuration for \"{provisioningDomain}\"" : "A(z) „{provisioningDomain}” beállítása",
    "Provisioning domain" : "Felügyeleti tartomány",
    "Email address template" : "E-mail-címsablon",
    "IMAP" : "IMAP",
    "User" : "Felhasználó",
    "Host" : "Kiszolgáló",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Master password" : "Mesterjelszó",
    "Use master password" : "Mesterjelszó használata",
    "Sieve" : "Levélszűrő",
    "Enable sieve integration" : "Levélszűrő integráció engedélyezése",
    "LDAP aliases integration" : "LDAP álnevek integrációja",
    "Enable LDAP aliases integration" : "LDAP álnevek integrációjának engedélyezése",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Az LDAP álnevek integrációja kiolvas egy attribútumot a beállított LDAP-címtárból az e-mail-címek álneveinek beállításához",
    "LDAP attribute for aliases" : "Az álnevek LDAP attribútuma",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Egy többértékű attribútum az e-mail-cím álneveinek beállításhoz. Az összes értékhez létrejön egy álnév. A Nextcloudban létező, de az LDAP címtárban nem szereplő álnevek törlésre kerülnek.",
    "Save Config" : "Konfiguráció mentése",
    "Unprovision & Delete Config" : "Felügyelet megszüntetése és konfiguráció törlése",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* a %USERID% és az %EMAIL% le lesz cserélve a felhasználó UID-jára és az e-mail-címére",
    "With the settings above, the app will create account settings in the following way:" : "A fenti beállításokkal az alkalmazás a következő módon hozza létre a fiókbeállításokat:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "A megadott PKCS #12 tanúsítványnak legalább egy tanúsítványt és pontosan egy titkos kulcsot kell tartalmaznia.",
    "Failed to import the certificate. Please check the password." : "A tanúsítvány importálása nem sikerült. Ellenőrizze a jelszót.",
    "Certificate imported successfully" : "Tanúsítvány sikeresen importálva",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "A tanúsítvány importálása sikertelen. Győződjön meg arról, hogy a privát kulcs megfelel a tanúsítványnak, és nem védi jelszó.",
    "Failed to import the certificate" : "A tanúsítvány importálása sikertelen",
    "S/MIME certificates" : "S/MIME tanúsítványok",
    "Certificate name" : "Tanúsítvány neve",
    "E-mail address" : "E-mail-cím",
    "Valid until" : "Érvényes",
    "Delete certificate" : "Tanúsítvány törlése",
    "No certificate imported yet" : "Még nincs tanúsítvány importálva",
    "Import certificate" : "Tanúsítvány importálása",
    "Import S/MIME certificate" : "S/MIME tanúsítvány importálása",
    "PKCS #12 Certificate" : "PKCS #12 tanúsítvány",
    "PEM Certificate" : "PEM-tanúsítvány",
    "Certificate" : "Tanúsítvány",
    "Private key (optional)" : "Titkos kulcs (nem kötelező)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "A titkos kulcs csak akkor szükséges, ha aláírt és titkosított e-maileket akar küldeni a tanúsítvány használatával.",
    "Submit" : "Beküldés",
    "Account connected" : "Fiók csatlakoztatva",
    "You can close this window" : "Bezárhatja ezt az ablakot",
    "Connect your mail account" : "Kapcsolódás az e-mail-fiókjához",
    "To add a mail account, please contact your administrator." : "Levelezőfiók hozzáadásához lépjen kapcsolatba a rendszergazdával.",
    "All" : "Összes",
    "Drafts" : "Piszkozatok",
    "Favorites" : "Kedvencek",
    "Priority inbox" : "Kiemelt bejövő levelek",
    "All inboxes" : "Összes bejövő levél",
    "Inbox" : "Bejövő",
    "Junk" : "Levélszemét",
    "Sent" : "Elküldött",
    "Trash" : "Lomtár",
    "Connect OAUTH2 account" : "Kapcsolódás OAUTH2-fiókhoz",
    "Error while sharing file" : "Hiba a fájl megosztása során",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n új üzenet \nfeladó: {from}","%n új üzenet \nfeladó: {from}"],
    "Nextcloud Mail" : "Nextcloud Levelezés",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Már van egy folyamatban lévő üzenet. Az összes mentetlen változtatás elvész, ha folytatja.",
    "Discard changes" : "Változtatások elvetése",
    "Discard unsaved changes" : "Mentetlen változtatások elvetése",
    "Keep editing message" : "Üzenet szerkesztésének folytatása",
    "Attachments were not copied. Please add them manually." : "A mellékleteket nem kerültek másolásra. Kérjük, adja hozzá őket manuálisan.",
    "Could not create snooze mailbox" : "Nem sikerült az altatott postafiók létrehozása",
    "Message sent" : "Üzenet elküldve",
    "Could not send message" : "Nem sikerült elküldeni az üzenetet",
    "Could not load {tag}{name}{endtag}" : "Nem sikerült betölteni: {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
    "Could not load your message" : "Nem sikerült betölteni az üzenetét",
    "Could not load the desired message" : "Nem sikerült betölteni a kért üzenetet",
    "Could not load the message" : "Nem sikerült betölteni az üzenetet",
    "Error loading message" : "Hiba történt az üzenet betöltése közben",
    "Forwarding to %s" : "Továbbítás ide: %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kattintson ide, ha a következő néhány másodpercben nem lenne automatikusan átirányítva.",
    "Redirect" : "Átirányítás",
    "The link leads to %s" : "A hivatkozás ide mutat: %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
    "Continue to %s" : "Folytatás ide: %s",
    "Actions" : "Műveletek",
    "New action" : "Új művelet"
},
"nplurals=2; plural=(n != 1);");
